.. index file for optional plugins

================
Optional Plugins
================

The following pages are the documentation for some of the Avocado
optional plugins:

.. toctree::
   :maxdepth: 1

   remote_runners
   results
   robot
   varianter_yaml_to_mux
   varianter_pict
   varianter_cit
   yaml_loader
   golang
   glib
   avocado_ec2
   azure
